@@ -3,7 +3,7 @@ use strict;
 
 package RT::Extension::FormTools;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ their own forms in Mason.
 
 =head1 RT VERSION
 
-Works with RT 4.0 and 4.2
+Works with RT 4.2.3+
 
 =head1 INSTALLATION
 
@@ -35,16 +35,10 @@ May need root permissions
 
 =item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
 
-If you are using RT 4.2 or greater, add this line:
+Add this line:
 
     Plugin('RT::Extension::FormTools');
 
-For RT 4.0, add this line:
-
-    Set(@Plugins, qw(RT::Extension::FormTools));
-
-or add C<RT::Extension::FormTools> to your existing C<@Plugins> line.
-
 =item Clear your mason cache
 
     rm -rf /opt/rt4/var/mason_data/obj
@@ -232,7 +226,7 @@ or via the web at
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2014-2018 by Best Practical Solutions
+This software is Copyright (c) 2014-2022 by Best Practical Solutions
 
 This is free software, licensed under:
 
